@@ -1,6 +1,15 @@
 inter_probs <-
 function(object,cutoff=0.75,n.burnin=0,thin=1){
 
+if(n.burnin<0){
+stop("n.burnin should be positive")}
+if(n.burnin>=length(object$MODEL)){
+stop("n.burnin should be less than the MCMC sample size (n.sample)")}
+if(thin<1){
+stop("thin should be greater than or equal to 1")}
+if(cutoff<0 | cutoff>1){
+stop("cutoff is a probability and should be between 0 and 1")}
+
 term.labels<-c("(Intercept)",attr(summary(object$maximal.mod)$terms,"term.labels"))
 term.numbers<-attributes(object$maximal.mod$x)$assign
 small<-function(i){
